LearningProjection
==================

.. automodule:: psyneulink.core.components.projections.modulatory.learningprojection
   :members:
   :private-members:
   :exclude-members: random, execute, Parameters
